@@ -15,6 +15,7 @@ from proglog import ProgressBarLogger
 from bgeditor.common.utils import get_dir
 import uuid, textwrap
 import math
+import traceback
 import json
 from moviepy.video.fx import make_loopable
 class MyBarLogger(ProgressBarLogger):
@@ -308,7 +309,6 @@ class Component:
                 data = {"id": self.job_id, "ori_text": ori_text}
                 return requests.post(self.mf_server+"job/text/replace",data=data).text
             except:
-                import traceback
                 traceback.print_exc()
                 return ""
                 pass
@@ -380,24 +380,30 @@ class Component:
         return self.audio_path
 
     def make(self):
-        self.get_audio()
-        rs = self.get_clip()
-        if self.audio_moviepy:
-          rs = rs.set_audio(self.audio_moviepy)
-        if self.type !='element':
-          rs = rs.set_position((self.position['x'], self.position['y']))
-        if self.duration > 0:
-            rs = rs.set_duration(self.duration).crossfadeout(0.5)
-        elif self.duration < 0:
-            rs = rs.set_duration(600)
+        rs=None
+        try:
+            self.get_audio()
+            rs = self.get_clip()
+            if self.audio_moviepy:
+              rs = rs.set_audio(self.audio_moviepy)
+            if self.type !='element':
+              rs = rs.set_position((self.position['x'], self.position['y']))
+            if self.duration > 0:
+                rs = rs.set_duration(self.duration).crossfadeout(0.5)
+            elif self.duration < 0:
+                rs = rs.set_duration(600)
 
-        if self.start_time > 0:
-            rs = rs.set_start(self.start_time).crossfadein(0.5)
-        if self.start_time == 0:
-            rs = rs.set_start(self.start_time)
-        if self.type !='element' and self.position['rotation'] != 0:
-            rs = rs.rotate(-1*self.position['rotation'])
-        self.rs=rs
+            if self.start_time > 0:
+                rs = rs.set_start(self.start_time).crossfadein(0.5)
+            if self.start_time == 0:
+                rs = rs.set_start(self.start_time)
+            if self.type !='element' and self.position['rotation'] != 0:
+                rs = rs.rotate(-1*self.position['rotation'])
+            self.rs=rs
+        except:
+            log_err=traceback.format_exc()
+            log_data=f"Error Make Component: index-{self.index} \n"+log_err
+            raise TypeError(log_data)
         return rs
     def close(self):
         try:
