@@ -131,10 +131,22 @@ def merge_intro_outro(clip_path, intro = None, outro = None):
     arrVids=[]
     if not intro and not outro:
         return clip_path
+    tmp_path_audio = os.path.join(get_dir('coolbg_ffmpeg'), str(uuid.uuid4()) + "-final-vid-audio.mp4")
+    cmd = f"ffmpeg -i \"{clip_path}\" -c:v copy -b:a 128000 -ar 44100 -c:a mp3 \"{tmp_path_audio}\""
+    os.system(cmd)
+    os.remove(clip_path)
     if intro:
+        # tmp_intro= os.path.join(get_dir('coolbg_ffmpeg'), str(uuid.uuid4()) + "-intro-vid-audio.mp4")
+        # cmd = f"ffmpeg -i \"{intro}\" -c:v libx264 -flags global_header -pix_fmt yuv420p -b:v 4M -crf 23 -r 24 -b:a 128000 -ar 44100 -c:a mp3 \"{tmp_intro}\""
+        # os.system(cmd)
+        # os.remove(intro)
         arrVids.append(intro)
-    arrVids.append(clip_path)
+    arrVids.append(tmp_path_audio)
     if outro:
+        # tmp_outro = os.path.join(get_dir('coolbg_ffmpeg'), str(uuid.uuid4()) + "-intro-vid-audio.mp4")
+        # cmd = f"ffmpeg -i \"{outro}\" -c:v libx264 -flags global_header -pix_fmt yuv420p -b:v 4M -crf 23 -r 24 -b:a 128000 -ar 44100 -c:a mp3 \"{tmp_outro}\""
+        # os.system(cmd)
+        # os.remove(outro)
         arrVids.append(outro)
     return merge_list_video(arrVids, True)
 
